@@ -1,19 +1,19 @@
-use plotpy::*;
+use plotpy::{Plot, Text};
 use std::fs::File;
 use std::io::{BufRead, BufReader};
 use std::path::Path;
 
-const OUT_DIR: &str = "/tmp/plotpy/integration_tests";
+const OUT_DIR: &str = "/tmp/plotpy/integ_tests";
 
 #[test]
 fn test_text() -> Result<(), &'static str> {
     // text object and options
     let mut text = Text::new();
-    text.color = "blue".to_string();
-    text.align_horizontal = "center".to_string();
-    text.align_vertical = "center".to_string();
-    text.font_size = 50.0;
-    text.rotation = 45.0;
+    text.set_color("blue")
+        .set_align_horizontal("center")
+        .set_align_vertical("center")
+        .set_fontsize(50.0)
+        .set_rotation(45.0);
 
     // draw text
     text.draw(0.5, 0.5, "message");
@@ -23,7 +23,7 @@ fn test_text() -> Result<(), &'static str> {
     plot.add(&text);
 
     // save figure
-    let path = Path::new(OUT_DIR).join("text.svg");
+    let path = Path::new(OUT_DIR).join("integ_text.svg");
     plot.save(&path)?;
 
     // check number of lines
